@@ -53,7 +53,7 @@ from threading import Thread
 
 __author__ = """Markus Gerstel"""
 __email__ = "scientificsoftware@diamond.ac.uk"
-__version__ = "0.8.1"
+__version__ = "0.9.0"
 
 logger = logging.getLogger("procrunner")
 logger.addHandler(logging.NullHandler())
@@ -82,7 +82,13 @@ class _LineAggregator(object):
         if "\n" in data:
             to_print, remainder = self._buffer.rsplit("\n")
             if self._print:
-                print(to_print)
+                try:
+                    print(to_print)
+                except UnicodeEncodeError:
+                    print(to_print.encode(sys.getdefaultencoding(), errors="replace"))
+                    if not hasattr(self, "_warned"):
+                        logger.warning("output encoding error, characters replaced")
+                        setattr(self, "_warned", True)
             if self._callback:
                 self._callback(to_print)
             self._buffer = remainder
